@@ -20,12 +20,8 @@ from selenium.webdriver.remote.webdriver import WebDriver as RemoteWebDriver
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 from selenium.webdriver.remote.command import Command
 from selenium.common.exceptions import WebDriverException
-from ctypes import *
-import time
-import os
 import base64
 from service import Service
-import warnings
 
 DEFAULT_TIMEOUT = 30
 DEFAULT_PORT = 0
@@ -38,30 +34,8 @@ class WebDriver(RemoteWebDriver):
         if self.port == 0:
             self.port = utils.free_port()
 
-        try:
-            self.iedriver = Service(executable_path, port=self.port)
-            self.iedriver.start()
-        except:
-            # Create IE Driver instance of the unmanaged code
-            try:
-                warnings.warn("You need to download the IEDriverServer. \
-                            Using the deprecated approach", DeprecationWarning)
-                self.iedriver = CDLL(os.path.join(os.path.dirname(__file__),"win32", "IEDriver.dll"))
-            except WindowsError:
-                try:
-                    self.iedriver = CDLL(os.path.join(os.path.dirname(__file__),"x64", "IEDriver.dll"))
-                except WindowsError:
-                    raise WebDriverException("Unable to load the IEDriver.dll component")
-            self.ptr = self.iedriver.StartServer(self.port)
-
-            seconds = 0
-            while not utils.is_url_connectable(self.port):
-                seconds += 1
-                if seconds > DEFAULT_TIMEOUT:
-                    # Clean up after ourselves
-                    self.quit()
-                    raise RuntimeError("Unable to connect to IE")
-                time.sleep(1)
+        self.iedriver = Service(executable_path, port=self.port)
+        self.iedriver.start()
 
         RemoteWebDriver.__init__(
             self,
@@ -70,12 +44,7 @@ class WebDriver(RemoteWebDriver):
 
     def quit(self):
         RemoteWebDriver.quit(self)
-        try:
-            self.iedriver.stop()
-        except:
-            self.iedriver.StopServer(self.ptr)
-            del self.iedriver
-            del self.ptr
+        self.iedriver.stop()
 
     def save_screenshot(self, filename):
         """
